summaryrefslogtreecommitdiffstats
path: root/libkdegames
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commitc406d61deefc0c3e3173ebe77bfb38a1bc453ce7 (patch)
tree12ccf93b39a8eedba87ebbd7447d33e5ab59108a /libkdegames
parent373fe6f2b90bcd2e452f16115a4950a4b46c1f34 (diff)
downloadtdegames-c406d61deefc0c3e3173ebe77bfb38a1bc453ce7.tar.gz
tdegames-c406d61deefc0c3e3173ebe77bfb38a1bc453ce7.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdegames')
-rw-r--r--libkdegames/kchatbase.cpp8
-rw-r--r--libkdegames/kchatbase.h32
-rw-r--r--libkdegames/kgame/kgameio.h4
3 files changed, 22 insertions, 22 deletions
diff --git a/libkdegames/kchatbase.cpp b/libkdegames/kchatbase.cpp
index 182f96a9..00827e6d 100644
--- a/libkdegames/kchatbase.cpp
+++ b/libkdegames/kchatbase.cpp
@@ -349,15 +349,15 @@ void KChatBase::addItem(const TQListBoxItem* text)
void KChatBase::addMessage(const TQString& fromName, const TQString& text)
{
//maybe "%1 says: %2" or so
- addItem(tqlayoutMessage(fromName, text));
+ addItem(layoutMessage(fromName, text));
}
void KChatBase::addSystemMessage(const TQString& fromName, const TQString& text)
{
- addItem(tqlayoutSystemMessage(fromName, text));
+ addItem(layoutSystemMessage(fromName, text));
}
-TQListBoxItem* KChatBase::tqlayoutMessage(const TQString& fromName, const TQString& text)
+TQListBoxItem* KChatBase::layoutMessage(const TQString& fromName, const TQString& text)
{
//TODO: KChatBaseConfigure? - e.g. color
TQListBoxItem* message;
@@ -379,7 +379,7 @@ TQListBoxItem* KChatBase::tqlayoutMessage(const TQString& fromName, const TQStri
return message;
}
-TQListBoxItem* KChatBase::tqlayoutSystemMessage(const TQString& fromName, const TQString& text)
+TQListBoxItem* KChatBase::layoutSystemMessage(const TQString& fromName, const TQString& text)
{
//TODO: KChatBaseConfigure? - e.g. color
diff --git a/libkdegames/kgame/kgameio.h b/libkdegames/kgame/kgameio.h
index 2f4b89ab..6f6a6ae9 100644
--- a/libkdegames/kgame/kgameio.h
+++ b/libkdegames/kgame/kgameio.h
@@ -187,7 +187,7 @@ public:
* handler signalKeyEvent and can be used to generate
* a valid move for the player.
* Note the widget you pass to the constructor must be
- * the main window of your application, e.g. view->tqparentWidget()
+ * the main window of your application, e.g. view->parentWidget()
* as QT does not forward your keyevents otherwise. This means
* that this might be a different widget comapred to the one you
* use for mouse inputs!
@@ -199,7 +199,7 @@ public:
* this,TQT_SLOT(slotKeyInput(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)));
* \endcode
*
- * @param tqparent The tqparents widget whose keyboard events * should be grabbed
+ * @param tqparent The parents widget whose keyboard events * should be grabbed
*/
KGameKeyIO(TQWidget *tqparent);
virtual ~KGameKeyIO();
diff --git a/libkdegames/kchatbase.h b/libkdegames/kchatbase.h
index 5e97b80c..77a6ed4f 100644
--- a/libkdegames/kchatbase.h
+++ b/libkdegames/kchatbase.h
@@ -171,8 +171,8 @@ class KChatBasePrivate;
*
* To add a message just call addMessage with the nickname of the player
* who sent the message and the message itself. If you don't want to use
* tqlayoutMessage by any reason you can also call addItem directly. But you
* should better replace tqlayoutMessage instead.
*
* You probably don't want to use the abstract class KChatBase directly but use
* one of the derived classess KChat or KGameChat. The latter is the
@@ -314,35 +314,35 @@ public:
/**
* Same as setNameFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
void setSystemNameFont(const TQFont& font);
/**
* Same as setMessageFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
void setSystemMessageFont(const TQFont& font);
/**
* Same as setBothFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
void setSystemBothFont(const TQFont& font);
/**
* This font should be used for the name (the "from: " part) of a
* message. tqlayoutMessage uses this to set the font using
* KChatBaseText::setNameFont but if you want to overwrite
* tqlayoutMessage you should do this yourself.
* @return The font that is used for the name part of the message.
**/
const TQFont& nameFont() const;
/**
* This font should be used for a message. tqlayoutMessage sets the
* font of a message using KChatBaseText::setMessageFont but if ypu
* replace tqlayoutMessage with your own function you should use
* messageFont() yourself.
* @return The font that is used for a message
**/
@@ -350,13 +350,13 @@ public:
/**
* Same as systemNameFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
const TQFont& systemNameFont() const;
/**
* Same as systemMessageFont but applies only to system messages.
- * @see tqlayoutSystemMessage
+ * @see layoutSystemMessage
**/
const TQFont& systemMessageFont() const;
@@ -406,7 +406,7 @@ public slots:
* Maybe you want to replace this with a function that creates a nicer text
* than "fromName: text"
*
* Update: the function tqlayoutMessage is called by this now. This
* means that you will get user defined outlook on the messages :-)
* @param fromName The player who sent this message
* @param text The text to be added
@@ -415,7 +415,7 @@ public slots:
/**
* This works just like addMessage but adds a system message.
* tqlayoutSystemMessage is used to generate the displayed item. System
* messages will have a different look than player messages.
*
* You may wish to use this to display status information from your game.
@@ -483,16 +483,16 @@ protected:
* created which shows the message in this format: "fromName: text".
* This should fit most peoples needs but needs further improvements.
**/
- virtual TQListBoxItem* tqlayoutMessage(const TQString& fromName, const TQString& text);
+ virtual TQListBoxItem* layoutMessage(const TQString& fromName, const TQString& text);
/**
* Create a TQListBoxItem for this message. This does the same as
* tqlayoutMessage but generates a system message. You might want to
* use such a message to display e.g. status information from your game.
*
* The default implementation just prepends "--- ".
**/
- virtual TQListBoxItem* tqlayoutSystemMessage(const TQString& fromName, const TQString& text);
+ virtual TQListBoxItem* layoutSystemMessage(const TQString& fromName, const TQString& text);
private slots:
/**
@@ -171,8 +171,8 @@ class KChatBasePrivate;
* To add a message just call addMessage with the nickname of the player
* who sent the message and the message itself. If you don't want to use
- * tqlayoutMessage by any reason you can also call addItem directly. But you
- * should better replace tqlayoutMessage instead.
+ * layoutMessage by any reason you can also call addItem directly. But you
+ * should better replace layoutMessage instead.
*
* You probably don't want to use the abstract class KChatBase directly but use
@@ -314,35 +314,35 @@ public:
/**
* This font should be used for the name (the "from: " part) of a
- * message. tqlayoutMessage uses this to set the font using
+ * message. layoutMessage uses this to set the font using
* KChatBaseText::setNameFont but if you want to overwrite
@@ -314,35 +314,35 @@ public:
* KChatBaseText::setNameFont but if you want to overwrite
- * tqlayoutMessage you should do this yourself.
+ * layoutMessage you should do this yourself.
* @return The font that is used for the name part of the message.
**/
@@ -314,35 +314,35 @@ public:
const TQFont& nameFont() const;
/**
- * This font should be used for a message. tqlayoutMessage sets the
+ * This font should be used for a message. layoutMessage sets the
* font of a message using KChatBaseText::setMessageFont but if ypu
@@ -314,35 +314,35 @@ public:
* font of a message using KChatBaseText::setMessageFont but if ypu
- * replace tqlayoutMessage with your own function you should use
+ * replace layoutMessage with your own function you should use
* messageFont() yourself.
* @return The font that is used for a message
@@ -406,7 +406,7 @@ public slots:
* than "fromName: text"
*
- * Update: the function tqlayoutMessage is called by this now. This
+ * Update: the function layoutMessage is called by this now. This
* means that you will get user defined outlook on the messages :-)
* @param fromName The player who sent this message
@@ -415,7 +415,7 @@ public slots:
/**
* This works just like addMessage but adds a system message.
- * tqlayoutSystemMessage is used to generate the displayed item. System
+ * layoutSystemMessage is used to generate the displayed item. System
* messages will have a different look than player messages.
*
@@ -483,16 +483,16 @@ protected:
/**
* Create a TQListBoxItem for this message. This does the same as
- * tqlayoutMessage but generates a system message. You might want to
+ * layoutMessage but generates a system message. You might want to
* use such a message to display e.g. status information from your game.
*